@@ -1,7 +1,7 @@
 from typing import BinaryIO
 
 from picamera2 import Picamera2  # type: ignore
-from picamera2.encoders import H264Encoder  # type: ignore
+from picamera2.encoders import H264Encoder, Quality  # type: ignore
 from picamera2.outputs import CircularOutput  # type: ignore
 
 
@@ -13,10 +13,22 @@ class Recorder:
 
     def __init__(self) -> None:
         self.picam2 = Picamera2()
-        self.picam2.configure(self.picam2.create_video_configuration())
-        self.encoder = H264Encoder()
-        self.output = CircularOutput()
-        self.picam2.start_recording(self.encoder, self.output)
+        fps = 25
+        dur = 10
+        micro = int((1 / fps) * 1000000)
+        vconfig = self.picam2.create_video_configuration(
+            main={"size": (2048, 1536)}, lores={"size": (800, 606)}, encode="lores"
+        )
+        vconfig["controls"]["FrameDurationLimits"] = (micro, micro)
+        self.picam2.configure(vconfig)
+        self.encoder = H264Encoder(
+            iperiod=1,
+            repeat=True,
+        )
+        self.output = CircularOutput(
+            buffersize=int(fps * (dur + 0.2)), outputtofile=False
+        )
+        self.picam2.start_recording(self.encoder, self.output, Quality.HIGH)
 
     def save_snippet_to(self, fp: BinaryIO) -> None:
         """
@@ -25,7 +37,6 @@ class Recorder:
         :return:
         """
         self.output.fileoutput = fp
-        self.output.start()
         self.output.stop()
 
     def __del__(self) -> None:
