@@ -11,7 +11,6 @@ logger = logging.getLogger()
 
 
 def main() -> None:
-    obsbt = ObsBT()
     recorder = Recorder()
 
     def record_callback(**kwargs) -> None:  # type: ignore
@@ -21,11 +20,12 @@ def main() -> None:
             open(target_dir / f"{kwargs['sensortime']}.h264", "wb")
         )
         json.dump(kwargs, open(target_dir / f"{kwargs['sensortime']}.json", "w"))
+        logger.info(f"savedd to {target_dir}")
 
-    obsbt.overtaking_callbacks.append(record_callback)
     while True:
         try:
             obsbt = ObsBT()
+            obsbt.overtaking_callbacks.append(record_callback)
             asyncio.run(obsbt.run())
-        except (ObsScannerError):
+        except ObsScannerError:
             logger.exception("Restarting bluetooth connection")
